BCLIBCFFI_BaseTrajInterpKey enum

Interpolation key for BCLIBC_BaseTrajData fields.

Inheritance
Available extensions

Values

BCLIBCFFI_INTERP_KEY_TIME → const BCLIBCFFI_BaseTrajInterpKey
const BCLIBCFFI_BaseTrajInterpKey(0)
BCLIBCFFI_INTERP_KEY_MACH → const BCLIBCFFI_BaseTrajInterpKey
const BCLIBCFFI_BaseTrajInterpKey(1)
BCLIBCFFI_INTERP_KEY_POS_X → const BCLIBCFFI_BaseTrajInterpKey
const BCLIBCFFI_BaseTrajInterpKey(2)
BCLIBCFFI_INTERP_KEY_POS_Y → const BCLIBCFFI_BaseTrajInterpKey
const BCLIBCFFI_BaseTrajInterpKey(3)
BCLIBCFFI_INTERP_KEY_POS_Z → const BCLIBCFFI_BaseTrajInterpKey
const BCLIBCFFI_BaseTrajInterpKey(4)
BCLIBCFFI_INTERP_KEY_VEL_X → const BCLIBCFFI_BaseTrajInterpKey
const BCLIBCFFI_BaseTrajInterpKey(5)
BCLIBCFFI_INTERP_KEY_VEL_Y → const BCLIBCFFI_BaseTrajInterpKey
const BCLIBCFFI_BaseTrajInterpKey(6)
BCLIBCFFI_INTERP_KEY_VEL_Z → const BCLIBCFFI_BaseTrajInterpKey
const BCLIBCFFI_BaseTrajInterpKey(7)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) BCLIBCFFI_BaseTrajInterpKey

Constants

values → const List<BCLIBCFFI_BaseTrajInterpKey>
A constant List of the values in this enum, in order of their declaration.