BCLIBCFFI_Error class final

Error output struct – filled by every function on failure.

Inheritance
Implemented types
Available extensions

Constructors

BCLIBCFFI_Error()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
code int
< BCLIBCFFI_Status
getter/setter pair
f64_0 double
< OutOfRange: requested_distance_ft / ZeroFinding: zero_finding_error
getter/setter pair
f64_1 double
< OutOfRange: max_range_ft / ZeroFinding: last_barrel_elevation_rad
getter/setter pair
f64_2 double
< OutOfRange: look_angle_rad
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
i32_0 int
< ZeroFinding: iterations_count
getter/setter pair
message Array<Char>
< Null-terminated error message
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited