Global physical and atmospheric constants for ballistic calculations. All constants follow international standards (ISA, ICAO).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- cA0 → const double
- cA1 → const double
- cA2 → const double
- cA3 → const double
- cA4 → const double
- cA5 → const double
- cDegreesCtoK → const double
- cDegreesFtoR → const double
- cDensityImperialToMetric → const double
- cEarthAngularVelocityRadS → const double
- cGravityImperial → const double
- cLapseRateImperial → const double
- cLapseRateKperFoot → const double
- cLapseRateMetric → const double
- cLowestTempF → const double
- cMaxWindDistanceFeet → const double
- cPressureExponent → const double
- cSpeedOfSoundImperial → const double
- cSpeedOfSoundMetric → const double
- cStandardDensity → const double
- cStandardDensityMetric → const double
- cStandardHumidity → const double
- cStandardPressure → const double
- cStandardPressureMetric → const double
- cStandardTemperatureC → const double
- cStandardTemperatureF → const double