BcBaseTrajInterpKey enum

Interpolation key for BcBaseTrajData fields (see BcLibC.integrateAtShot-style calls).

Inheritance
Available extensions

Values

time → const BcBaseTrajInterpKey
const BcBaseTrajInterpKey(0)
mach → const BcBaseTrajInterpKey
const BcBaseTrajInterpKey(1)
posX → const BcBaseTrajInterpKey
const BcBaseTrajInterpKey(2)
posY → const BcBaseTrajInterpKey
const BcBaseTrajInterpKey(3)
posZ → const BcBaseTrajInterpKey
const BcBaseTrajInterpKey(4)
velX → const BcBaseTrajInterpKey
const BcBaseTrajInterpKey(5)
velY → const BcBaseTrajInterpKey
const BcBaseTrajInterpKey(6)
velZ → const BcBaseTrajInterpKey
const BcBaseTrajInterpKey(7)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BcBaseTrajInterpKey>
A constant List of the values in this enum, in order of their declaration.