BcConfig class

Constructors

BcConfig({double stepMultiplier = 1.0, double zeroFindingAccuracy = 0.001, double minimumVelocity = 50.0, double maximumDrop = -15000.0, int maxIterations = 50, double gravityConstant = -32.17405, double minimumAltitude = -1000.0})
const

Properties

gravityConstant → double
final
hashCode → int
The hash code for this object.
no setterinherited
maximumDrop → double
final
maxIterations → int
final
minimumAltitude → double
final
minimumVelocity → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stepMultiplier → double
final
zeroFindingAccuracy → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited