BcException class

Implemented types

Constructors

BcException({required int code, required String message, double? requestedDistanceFt, double? maxRangeFt, double? lookAngleRad, double? zeroFindingError, double? lastBarrelElevationRad, int? iterationsCount})
const

Properties

code int
final
hashCode int
The hash code for this object.
no setterinherited
iterationsCount int?
final
lastBarrelElevationRad double?
final
lookAngleRad double?
final
maxRangeFt double?
final
message String
final
requestedDistanceFt double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zeroFindingError double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited