BcShot class

Shot descriptor in natural units.

All physics conversions (atmosphere density, Coriolis trig, PCHIP drag curve, cant sin/cos) are performed inside C++ by BCLIBC_Shot::to_shot_props().

latitudeDeg / azimuthDeg: pass double.nan to disable Coriolis (flat-fire only). pressureHpa == 0: vacuum (zero drag).

Constructors

BcShot({required double bc, required double weightGrain, required double diameterInch, required double lengthInch, required double muzzleVelocityFps, required double sightHeightFt, required double twistInch, required double tempC, required double pressureHpa, required double altitudeFt, double humidity = 0.0, required List<BcDragPoint> dragTable, List<BcWind> winds = const [], required double lookAngleRad, required double barrelElevationRad, double barrelAzimuthRad = 0.0, double cantAngleRad = 0.0, double latitudeDeg = double.nan, double azimuthDeg = double.nan, BcConfig config = const BcConfig(), BcIntegrationMethod method = BcIntegrationMethod.rk4})
const

Properties

altitudeFt double
final
azimuthDeg double
final
barrelAzimuthRad double
final
barrelElevationRad double
final
bc double
final
cantAngleRad double
final
config BcConfig
final
diameterInch double
final
dragTable List<BcDragPoint>
final
hashCode int
The hash code for this object.
no setterinherited
humidity double
final
latitudeDeg double
final
lengthInch double
final
lookAngleRad double
final
method BcIntegrationMethod
final
muzzleVelocityFps double
final
pressureHpa double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sightHeightFt double
final
tempC double
final
twistInch double
final
weightGrain double
final
winds List<BcWind>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited