BcTrajectoryData class

Constructors

BcTrajectoryData({required double time, required double distanceFt, required double velocityFps, required double mach, required double heightFt, required double slantHeightFt, required double dropAngleRad, required double windageFt, required double windageAngleRad, required double slantDistanceFt, required double angleRad, required double densityRatio, required double drag, required double energyFtLb, required double ogwLb, required int flag})
const

Properties

angleRad double
final
densityRatio double
final
distanceFt double
final
drag double
final
dropAngleRad double
final
energyFtLb double
final
flag int
final
hashCode int
The hash code for this object.
no setterinherited
heightFt double
final
mach double
final
ogwLb double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slantDistanceFt double
final
slantHeightFt double
final
time double
final
velocityFps double
final
windageAngleRad double
final
windageFt double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited