BcTrajectoryRequest class

Constructors

BcTrajectoryRequest({required double rangeLimitFt, required double rangeStepFt, double timeStep = 0.0, int filterFlags = 8})
const

Properties

filterFlags int
BCLIBCFFI_TrajFlag bitmask (may combine multiple flags via bitwise OR)
final
hashCode int
The hash code for this object.
no setterinherited
rangeLimitFt double
final
rangeStepFt double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeStep double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited