BcWind class

Constructors

BcWind({required double velocityFps, required double directionFromRad, double untilDistanceFt = 1e9, double maxDistanceFt = 1e9})
const

Properties

directionFromRad → double
final
hashCode → int
The hash code for this object.
no setterinherited
maxDistanceFt → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
untilDistanceFt → double
final
velocityFps → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited