Coriolis class

Properties

cosAz → double?
final
cosLat → double
final
crossEast → double?
final
crossNorth → double?
final
flatFireOnly → bool
final
hashCode → int
The hash code for this object.
no setterinherited
isFull3d → bool
no setter
muzzleVelocityFps → double
final
rangeEast → double?
final
rangeNorth → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sinAz → double?
final
sinLat → double
final

Methods

adjustPosition(double time, Vector position) → Vector
coriolisAccelerationLocal(Vector velocity) → Vector
flatFireOffsets(double time, double distanceFt, double dropFt) → (double, double)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create({double? latitude, double? azimuth, required double muzzleVelocityFps}) → Coriolis?