TrajFlag enum

Inheritance
Available extensions

Values

none → const TrajFlag
const TrajFlag(0)
zeroUp → const TrajFlag
const TrajFlag(1)
zeroDown → const TrajFlag
const TrajFlag(2)
zero → const TrajFlag
const TrajFlag(3)
mach → const TrajFlag
const TrajFlag(4)
range → const TrajFlag
const TrajFlag(8)
apex → const TrajFlag
const TrajFlag(16)
mrt → const TrajFlag
const TrajFlag(32)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getName(int flagValue) String

Constants

values → const List<TrajFlag>
A constant List of the values in this enum, in order of their declaration.