Vacuum class

Inheritance

Constructors

Vacuum({Distance? altitude, Temperature? temperature})

Properties

altitude → Distance
no setterinherited
densityImperial → double
no setterinherited
densityMetric → double
no setterinherited
densityRatio → double
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
humidity ↔ double
getter/setter pairinherited
mach → Velocity
no setterinherited
powderTemp → Temperature
no setterinherited
pressure → Pressure
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
temperature → Temperature
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateDensityRatio() → void
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

cLowestTempC → double
final