BCLIBCFFI_BaseTrajData class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- mach ↔ double
-
getter/setter pair
- px ↔ double
-
< Position x (downrange, ft)
getter/setter pair
- py ↔ double
-
< Position y (height, ft)
getter/setter pair
- pz ↔ double
-
< Position z (windage, ft)
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- time ↔ double
-
getter/setter pair
- vx ↔ double
-
< Velocity x (fps)
getter/setter pair
- vy ↔ double
-
< Velocity y (fps)
getter/setter pair
- vz ↔ double
-
< Velocity z (fps)
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited