BcBaseTrajData class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- mach → double
-
final
- px → double
-
final
- py → double
-
final
- pz → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- time → double
-
final
- vx → double
-
final
- vy → double
-
final
- vz → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited