BcLibC class
- Implemented types
Constructors
- BcLibC.open()
-
Open the native library. Call once per isolate.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
calculateEnergy(
double bulletWeightGrain, double velocityFps) → double -
override
-
calculateOgw(
double bulletWeightGrain, double velocityFps) → double -
override
-
findApexShot(
BcShot shot) → BcTrajectoryData -
override
-
findMaxRangeShot(
BcShot shot, {double lowAngleDeg = 0.0, double highAngleDeg = 45.0}) → BcMaxRangeResult -
override
-
findZeroAngleShot(
BcShot shot, double distanceFt) → double -
override
-
getCorrection(
double distanceFt, double offsetFt) → double -
override
-
integrateAtShot(
BcShot shot, BcBaseTrajInterpKey key, double targetValue) → BcInterception -
override
-
integrateShot(
BcShot shot, BcTrajectoryRequest request) → BcHitResult -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited